pub enum CloudError {
Show 18 variants
Storage(String),
Network(String),
Authentication(String),
Authorization(String),
NotFound(String),
AlreadyExists(String),
InvalidConfig(String),
Transfer(String),
ChecksumMismatch {
expected: String,
actual: String,
},
QuotaExceeded(String),
ServiceUnavailable(String),
Timeout(String),
Serialization(String),
MediaService(String),
Encryption(String),
InvalidParameter(String),
RateLimitExceeded(String),
Other(String),
}Expand description
Errors that can occur during cloud operations
Variants
Storage(String)
Storage operation failed
Network(String)
Network error
Authentication(String)
Authentication failed
Authorization(String)
Authorization failed
NotFound(String)
Object not found
AlreadyExists(String)
Object already exists
InvalidConfig(String)
Invalid configuration
Transfer(String)
Transfer error
ChecksumMismatch
Checksum mismatch
QuotaExceeded(String)
Quota exceeded
Service unavailable
Timeout(String)
Timeout error
Serialization(String)
Serialization error
MediaService(String)
Media service error
Encryption(String)
Encryption error
InvalidParameter(String)
Invalid parameter
RateLimitExceeded(String)
Rate limit exceeded
Other(String)
Generic error
Implementations
Sourceimpl CloudError
impl CloudError
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Check if the error is retryable
Sourcepub fn is_client_error(&self) -> bool
pub fn is_client_error(&self) -> bool
Check if the error is a client error (4xx)
Sourcepub fn is_server_error(&self) -> bool
pub fn is_server_error(&self) -> bool
Check if the error is a server error (5xx)